@@ -230,7 +230,6 @@ checkInputEstimatePrevalence <- function(cdm,
                                          outcomeTable,
                                          denominatorCohortId,
                                          outcomeCohortId,
-                                         outcomeLookbackDays,
                                          type,
                                          interval,
                                          completeDatabaseIntervals,
@@ -284,10 +283,6 @@ checkInputEstimatePrevalence <- function(cdm,
     add = errorMessage,
     null.ok = TRUE
   )
-  checkmate::assert_numeric(outcomeLookbackDays,
-    add = errorMessage,
-    null.ok = TRUE
-  )
   checkmate::assert_choice(type,
     choices = c("point", "period"),
     add = errorMessage
