@@ -16,7 +16,7 @@ library(tibble)
 library(tidyr)
 library(ggplot2)
 
-## ----echo=FALSE, message=FALSE, out.width="80%"-------------------------------
+## ----echo=FALSE, message=FALSE, out.width="80%", warning=FALSE----------------
 library(knitr)
 library(here)
 knitr::include_graphics(here("vignettes/dpop1.png"))
@@ -88,7 +88,7 @@ cdm <- generateDenominatorCohortSet(
   cdm = cdm,
   name = "denominator", 
   overwrite = TRUE,
-  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2010-01-01")),
+  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2009-12-31")),
   ageGroup = list(c(0, 150)),
   sex = "Both",
   daysPriorObservation = 0
@@ -137,7 +137,7 @@ cdm <- generateDenominatorCohortSet(
   cdm = cdm,
   name = "denominator",
   overwrite = TRUE,
-  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2010-01-01")),
+  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2009-12-31")),
   ageGroup = list(c(0, 150)),
   sex = "Both",
   daysPriorObservation = 365
@@ -186,7 +186,7 @@ cdm <- generateDenominatorCohortSet(
   cdm = cdm,
   name = "denominator",
   overwrite = TRUE,
-  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2010-01-01")),
+  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2009-12-31")),
   ageGroup = list(c(18, 65)),
   sex = "Female",
   daysPriorObservation = 365
@@ -218,11 +218,17 @@ cdm$denominator %>%
   )
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
+cdm <- mockIncidencePrevalenceRef(sampleSize = 500, 
+                                  earliestObservationStartDate = as.Date("2000-01-01"),
+                                  latestObservationStartDate =  as.Date("2005-01-01"),
+                                  minDaysToObservationEnd = 10000, 
+                                  earliestDateOfBirth = as.Date("1960-01-01"), 
+                                  latestDateOfBirth = as.Date("1980-01-01"))
+
 cdm <- generateDenominatorCohortSet(
   cdm = cdm,
   name = "denominator",
   overwrite = TRUE,
-  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2010-01-01")),
   ageGroup = list(
     c(0, 40),
     c(41, 100)
@@ -230,25 +236,15 @@ cdm <- generateDenominatorCohortSet(
   sex = "Both",
   daysPriorObservation = 0
 )
-dpop <- cdm$denominator %>%
-  collect() %>%
-  left_join(cohortSet(cdm$denominator))
-
-dpop %>%
-  glimpse()
-
-dpop %>%
-  group_by(cohort_definition_id, age_group) %>%
-  tally()
-
-dpop %>%
-  filter(subject_id %in% c("1", "3", "57", "353", "393", "496")) %>%
+cdm$denominator %>%
+  filter(subject_id %in% !!as.character(seq(1:30))) %>%
   collect() %>%
   pivot_longer(cols = c(
     "cohort_start_date",
     "cohort_end_date"
   )) %>%
-  mutate(cohort_definition_id = as.character(cohort_definition_id)) %>%
+  mutate(cohort_definition_id = as.character(cohort_definition_id),
+         subject_id = factor(as.numeric(subject_id))) %>%
   ggplot(aes(x = subject_id, y = value, colour = cohort_definition_id)) +
   geom_point(position = position_dodge(width = 0.5)) +
   geom_line(position = position_dodge(width = 0.5)) +
@@ -257,12 +253,13 @@ dpop %>%
   ylab("Year") +
   coord_flip()
 
+
+
 ## ----message=FALSE, warning=FALSE, fig.height=8-------------------------------
 cdm <- generateDenominatorCohortSet(
   cdm = cdm,
   name = "denominator",
   overwrite = TRUE,
-  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2010-01-01")),
   ageGroup = list(
     c(0, 40),
     c(41, 100)
@@ -270,25 +267,18 @@ cdm <- generateDenominatorCohortSet(
   sex = c("Male", "Female", "Both"),
   daysPriorObservation = 0
 )
-dpop <- cdm$denominator %>%
+cdm$denominator %>%
+  filter(subject_id %in% !!as.character(seq(1:15))) %>%
   collect() %>%
-  left_join(cohortSet(cdm$denominator))
-
-dpop %>% glimpse()
-
-dpop %>%
-  group_by(cohort_definition_id, age_group, sex) %>%
-  tally()
-
-dpop %>%
-  filter(subject_id %in% c("1", "3", "57", "353", "393", "496")) %>%
+  left_join(cohortSet(cdm$denominator)) %>%
   pivot_longer(cols = c(
     "cohort_start_date",
     "cohort_end_date"
   )) %>%
-  mutate(cohort_definition_id = as.character(cohort_definition_id)) %>%
+  mutate(cohort_definition_id = as.character(cohort_definition_id),
+         subject_id = factor(as.numeric(subject_id))) %>%
   ggplot(aes(x = subject_id, y = value, colour = cohort_definition_id)) +
-  facet_grid(sex ~ ., space = "free_y") +
+    facet_grid(sex ~ ., space = "free_y") +
   geom_point(position = position_dodge(width = 0.5)) +
   geom_line(position = position_dodge(width = 0.5)) +
   theme_bw() +
@@ -296,12 +286,12 @@ dpop %>%
   ylab("Year") +
   coord_flip()
 
+
 ## ----message=FALSE, warning=FALSE, fig.height=10------------------------------
 cdm <- generateDenominatorCohortSet(
   cdm = cdm,
   name = "denominator",
   overwrite = TRUE,
-  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2010-01-01")),
   ageGroup = list(
     c(0, 40),
     c(41, 100)
@@ -309,23 +299,16 @@ cdm <- generateDenominatorCohortSet(
   sex = c("Male", "Female", "Both"),
   daysPriorObservation = c(0, 365)
 )
-dpop <- cdm$denominator %>%
+cdm$denominator %>%
+  filter(subject_id %in% !!as.character(seq(1:15))) %>%
   collect() %>%
-  left_join(cohortSet(cdm$denominator))
-
-dpop %>% glimpse()
-
-dpop %>%
-  group_by(cohort_definition_id, age_group, sex, days_prior_observation) %>%
-  tally()
-
-dpop %>%
-  filter(subject_id %in% c("1", "3", "57", "353", "393", "496")) %>%
+  left_join(cohortSet(cdm$denominator)) %>%
   pivot_longer(cols = c(
     "cohort_start_date",
     "cohort_end_date"
   )) %>%
-  mutate(cohort_definition_id = as.character(cohort_definition_id)) %>%
+  mutate(cohort_definition_id = as.character(cohort_definition_id),
+         subject_id = factor(as.numeric(subject_id))) %>%
   ggplot(aes(x = subject_id, y = value, colour = cohort_definition_id)) +
   facet_grid(sex + days_prior_observation ~ ., space = "free_y") +
   geom_point(position = position_dodge(width = 0.5)) +
@@ -335,48 +318,36 @@ dpop %>%
   ylab("Year") +
   coord_flip()
 
+
 ## ----message=FALSE, warning=FALSE, fig.height=10------------------------------
 cdm <- generateDenominatorCohortSet(
   cdm = cdm,
   name = "denominator",
   overwrite = TRUE,
-  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2010-01-01")),
   ageGroup = list(
-    c(0, 100),
     c(0, 40),
     c(41, 100)
   ),
-  sex = c("Both", "Male", "Female"),
+  sex = c("Male", "Female", "Both"),
   daysPriorObservation = c(0, 365),
   requirementInteractions = FALSE
 )
-dpop <- cdm$denominator %>%
+cdm$denominator %>%
+  filter(subject_id %in% !!as.character(seq(1:15))) %>%
   collect() %>%
-  left_join(cohortSet(cdm$denominator))
-
-dpop %>% glimpse()
-
-dpop %>%
-  group_by(cohort_definition_id, age_group, sex, days_prior_observation) %>%
-  tally()
-
-dpop %>%
-  dplyr::slice_sample(prop = 0.1) %>%
+  left_join(cohortSet(cdm$denominator)) %>%
   pivot_longer(cols = c(
     "cohort_start_date",
     "cohort_end_date"
   )) %>%
-  mutate(cohort_definition_id = as.character(cohort_definition_id)) %>%
+  mutate(cohort_definition_id = as.character(cohort_definition_id),
+         subject_id = factor(as.numeric(subject_id))) %>%
   ggplot(aes(x = subject_id, y = value, colour = cohort_definition_id)) +
-  facet_grid(sex + days_prior_observation ~ age_group, space = "free_y") +
+  facet_grid(sex + days_prior_observation ~ ., space = "free_y") +
   geom_point(position = position_dodge(width = 0.5)) +
   geom_line(position = position_dodge(width = 0.5)) +
   theme_bw() +
-  theme(
-    axis.text.y = element_blank(),
-    axis.ticks.y = element_blank(),
-    legend.position = "top"
-  ) +
+  theme(legend.position = "top") +
   ylab("Year") +
   coord_flip()
 
@@ -385,7 +356,7 @@ cdm <- generateDenominatorCohortSet(
   cdm = cdm,
   name = "denominator",
   overwrite = TRUE,
-  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2010-01-01")),
+  cohortDateRange = c(as.Date("2008-01-01"), as.Date("2009-12-31")),
   ageGroup = list(
     c(0, 18),
     c(19, 100)
@@ -397,150 +368,14 @@ cdm <- generateDenominatorCohortSet(
 head(cdm$denominator, 8)
 
 ## ----message=TRUE, warning=FALSE----------------------------------------------
-cohortSet(cdm$denominator)
+cohortSet(cdm$denominator) %>% 
+  glimpse()
 
 ## ----message=TRUE, warning=FALSE----------------------------------------------
-cohortCount(cdm$denominator)
+cohortCount(cdm$denominator) %>% 
+  glimpse()
 
 ## ----message=TRUE, warning=FALSE----------------------------------------------
-cohortAttrition(cdm$denominator)
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-personTable <- tibble(
-  person_id = c("1", "2", "3", "4", "5"),
-  gender_concept_id = c(rep("8507", 2), rep("8532", 3)),
-  year_of_birth = 2000,
-  month_of_birth = 06,
-  day_of_birth = 01
-)
-observationPeriodTable <- tibble(
-  observation_period_id = "1",
-  person_id = c("1", "2", "3", "4", "5"),
-  observation_period_start_date = c(
-    as.Date("2010-12-19"),
-    as.Date("2005-04-01"),
-    as.Date("2009-04-10"),
-    as.Date("2010-08-20"),
-    as.Date("2010-01-01")
-  ),
-  observation_period_end_date = c(
-    as.Date("2011-06-19"),
-    as.Date("2005-11-29"),
-    as.Date("2016-01-02"),
-    as.Date("2011-12-11"),
-    as.Date("2015-06-01")
-  )
-)
-
-## ----message=FALSE, warning=FALSE, results='hide'-----------------------------
-conditionX <- tibble(
-  cohort_definition_id = c(rep("1", 3), rep("2", 3), rep("3", 5)),
-  subject_id = c("1", "2", "4", "3", "5", "2", "3", "3", "5", "5", "2"),
-  cohort_start_date = c(
-    as.Date("2010-12-19"),
-    as.Date("2005-04-01"),
-    as.Date("2010-08-20"),
-    as.Date("2012-01-01"),
-    as.Date("2010-06-01"),
-    as.Date("2005-08-20"),
-    as.Date("2012-01-01"),
-    as.Date("2015-06-01"),
-    as.Date("2014-10-01"),
-    as.Date("2010-06-01"),
-    as.Date("2005-08-20")
-  ),
-  cohort_end_date = c(
-    as.Date("2011-06-19"),
-    as.Date("2005-11-29"),
-    as.Date("2011-12-11"),
-    as.Date("2013-01-01"),
-    as.Date("2012-03-01"),
-    as.Date("2005-11-29"),
-    as.Date("2013-01-01"),
-    as.Date("2015-12-31"),
-    as.Date("2015-04-01"),
-    as.Date("2010-06-01"),
-    as.Date("2005-08-20")
-  )
-)
-
-# mock database
-cdm <- mockIncidencePrevalenceRef(
-  personTable = personTable,
-  observationPeriodTable = observationPeriodTable,
-  targetCohortTable = conditionX
-)
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-cdm <- generateDenominatorCohortSet(
-  cdm = cdm, 
-  name = "denominator",
-  overwrite = TRUE
-)
-cdm$denominator
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-observationPeriodTable
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-cdm <- generateDenominatorCohortSet(
-  cdm = cdm, 
-  name = "denominator",
-  overwrite = TRUE,
-  targetCohortTable = "target",
-  targetCohortId = 1
-)
-cdm$denominator
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-library(dplyr)
-observationPeriodTable %>%
-  filter(person_id %in% c("1", "2", "4"))
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-cdm <- generateDenominatorCohortSet(
-  cdm = cdm, 
-  name = "denominator",
-  overwrite = TRUE,
-  targetCohortTable = "target",
-  targetCohortId = 2
-)
-cdm$denominator
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-conditionX %>%
-  filter(cohort_definition_id == 2) %>%
-  filter(subject_id %in% c("2", "3", "5"))
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-cdm <- generateDenominatorCohortSet(
-  cdm = cdm, 
-  name = "denominator",
-  overwrite = TRUE,
-  targetCohortTable = "target",
-  targetCohortId = 3
-)
-cdm$denominator
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-conditionX %>%
-  filter(cohort_definition_id == 3) %>%
-  filter(subject_id %in% c("2", "3", "5"))
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-cdm <- generateDenominatorCohortSet(
-  cdm = cdm, 
-  name = "denom_reqs_at_target_entry",
-  overwrite = TRUE,
-  cohortDateRange = c(as.Date("2014-01-01"), as.Date("2016-01-01")),
-  ageGroup = list(c(15, 25)),
-  sex = "Female",
-  daysPriorObservation = 0,
-  targetCohortTable = "target",
-  targetCohortId = 3
-)
-cdm$denom_reqs_at_target_entry
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-cohortSet(cdm$denominator)
+cohortAttrition(cdm$denominator) %>% 
+  glimpse()
 
